//XmlNode.h
#ifndef __XMLNODE_H
#define __XMLNODE_H

#include <list>
#include <string>
#include <vector>
#include "tinyxml.h"

class XmlNode;
typedef std::vector<XmlNode*> XmlNodeVector;


class XmlNode
{
public:
	XmlNode();
	virtual	~XmlNode();

	XmlNode*		AttachChild( XmlNode* pChild );
	void			DetachChild( XmlNode* pChild );
	XmlNode*		GetRoot();
	XmlNode*		GetParent();

	XmlNode&		SetData( std::string data );
	XmlNode&		SetData( const char* pData );
	std::string*	GetData();
	static void		PrintAll( XmlNode* pNode );
	static void		WriteXml( XmlNode* pNode, TiXmlNode* pXml );
	
	std::string*	GetName();
	XmlNode&		SetName( const char* szName );
	void			AddAttribute( const char* pName, const char* pValue );
	void			FindNode( const char* pName, XmlNodeVector& nodeArr );

protected:
	void			FindNodeAll( const std::vector<std::string>& tok, int iDepth, XmlNodeVector& nodeArr );

protected:
	struct Attribute
	{
		std::string name;
		std::string value;

		Attribute( const char* _name, const char* _value )
		{
			name = _name;
			value = _value;
		}
	};
	typedef std::list <XmlNode*>		ChildList;
	typedef std::vector <Attribute*>	AttributeList;

	std::string		m_data;
	std::string		m_name;
	XmlNode*		m_pParent;
	ChildList		m_child;  
	AttributeList	m_attribute;
};

void		WriteXml( const char* szName, XmlNode* root );
XmlNode*	ReadXml( const char* szName );
XmlNode*	CreateXmlNode( char* szName );

#endif